@@ -6,15 +6,20 @@ Mad::Mapper - Map Perl objects to MySQL or PostgreSQL row data
 
 =head1 VERSION
 
-0.04
+0.05
 
 =head1 DESCRIPTION
 
 L<Mad::Mapper> is base class for objects that should be stored to the a
 persistent SQL database. Currently the supported backends are L<Mojo::Pg>
-or L<Mojo::mysql>, both which are optional dependencies.
+L<Mojo::mysql> and L<Mojo::SQLite>. These backends need to be installed
+separately.
 
-THIS MODULE IS EXPERIMENTAL!
+  $ cpanm Mad::Mapper
+  $ cpanm Mojo::Pg # Mad::Mapper now support postgres!
+
+THIS MODULE IS EXPERIMENTAL. It is in use in production though, so
+big changes will not be made without extreme consideration.
 
 =head1 SYNOPSIS
 
@@ -51,7 +56,7 @@ the simple C<_insert()> method above can be done complex:
         my ($delay, $err, $res) = @_;
         return $self->$cb($err) if $err;
         $self->in_storage(1);
-        $self->id($res->sth->mysql_insertid);
+        $self->id($db->dbh->last_insert_id(undef, undef, $self->table, $self->pk));
         $self->$cb("");
       },
     );
@@ -145,7 +150,7 @@ use Mojo::Loader 'load_class';
 use Scalar::Util 'weaken';
 use constant DEBUG => $ENV{MAD_DEBUG} || 0;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 my (%COLUMNS, %LOADED, %PK);
 
@@ -488,19 +493,25 @@ sub _find_sst {
 sub _insert {
   my ($self, $cb) = @_;
   my $pk  = $self->_pk_or_first_column;
+  my $db  = $self->db;
   my @sst = $self->_insert_sst;
 
   warn "[Mad::Mapper::insert] ", Mojo::JSON::encode_json(\@sst), "\n" if DEBUG;
 
   if ($cb) {
     weaken $self;
-    $self->db->query(
+    $db->query(
       @sst,
       sub {
         my ($db, $err, $res) = @_;
         warn "[Mad::Mapper::insert] err=$err\n" if DEBUG and $err;
         $res = eval { $res->hash } || {};
-        $res->{$pk} ||= eval { $res->sth->mysql_insertid } if $pk;
+
+        if ($pk) {
+          $res->{$pk} ||= $db->dbh->last_insert_id(undef, undef, $self->table, $self->pk);
+          $res->{$pk} ||= eval { $res->sth->mysql_insertid };    # can probably be removed
+        }
+
         $self->in_storage(1) if keys %$res;
         $self->$_($res->{$_}) for grep { $self->can($_) } keys %$res;
         $self->$cb($err);
@@ -508,9 +519,14 @@ sub _insert {
     );
   }
   else {
-    my $res = $self->db->query(@sst);
+    my $res = $db->query(@sst);
     $res = eval { $res->hash } || {};
-    $res->{$pk} ||= eval { $res->sth->mysql_insertid } if $pk;
+
+    if ($pk) {
+      $res->{$pk} ||= $db->dbh->last_insert_id(undef, undef, $self->table, $self->pk);
+      $res->{$pk} ||= eval { $res->sth->mysql_insertid }    # can probably be removed;
+    }
+
     $self->in_storage(1) if keys %$res;
     $self->$_($res->{$_}) for grep { $self->can($_) } keys %$res;    # used with Mojo::Pg and RETURNING
   }
